==> nextcloud-14.0.13.zip: nextcloud/apps/files_sharing/l10n/sq.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Shared with others" : "Të ndara me të tjerët",
    "Shared with you" : "Të ndara me ju",
    "Shared by link" : "Të ndara me lidhje",
    "Nothing shared with you yet" : "Ende pa ndarë gjë me ju",
    "Files and folders others share with you will show up here" : "Këtu do të shfaqen kartelat dhe dosjet që të jerët ndajnë me ju",
    "Nothing shared yet" : "Ende pa ndarë gjë",
    "Files and folders you share will show up here" : "Këtu do të shfaqen kartelat dhe dosjet që ndani me të tjerët",
    "No shared links" : "Pa lidhje ndarjesh",
    "Files and folders you share by link will show up here" : "Këtu do të shfaqen kartelat dhe dosjet që ndani përmes lidhjesh",
    "Download" : "Shkarko",
    "You can upload into this folder" : "Mund të ngarkoni te kjo dosje",
    "No compatible server found at {remote}" : "Asnjë server i pajtueshëm nuk është gjetur tek { }",
    "Invalid server URL" : "Server i pavlefshëm URL",
    "Failed to add the public link to your Nextcloud" : "Nuk arritët të shtoni ndërlidhjen publike tek Nextcloud juaj",
    "No expiration date set" : "Nuk është vendosur data e përfundimit",
    "Shared by" : "Ndarë nga",
    "File shares" : "Ndarja e skedarëve",
    "Downloaded via public link" : "Shkarkuar nga një link publik",
    "Downloaded by {email}" : "Shkarkuar nga {email}",
    "{file} downloaded via public link" : "{file} shkarkuar përmes një lidhjeje publike",
    "{email} downloaded {file}" : "{email} shkarkoi {file}",
    "Shared with group {group}" : "U nda me grupin {group}",
    "Removed share for group {group}" : "Hoqi ndarjen për grupin {group}",
    "{actor} shared with group {group}" : "{actor} u nda me grupin {group}",
    "{actor} removed share for group {group}" : "{actor} hoqi ndarjen për grupin {group}",
    "You shared {file} with group {group}" : "Ndatë {file} me grupin {group}",
    "You removed group {group} from {file}" : "Hoqët grupin {group} nga {file}",
    "{actor} shared {file} with group {group}" : "{actor} ndau {file} me grupin {group}",
    "{actor} removed group {group} from {file}" : "{actor} hoqi grupin {group} nga {file}",
    "Shared as public link" : "U nda si një lidhje publike",
    "Removed public link" : "Hoqi lidhje publike",
    "Public link expired" : "Lidhja publike skadoi",
    "{actor} shared as public link" : "{actor} u nda si një lidhje publike",
    "{actor} removed public link" : "{actor} hoqi lidhje publike",
    "Public link of {actor} expired" : "Lidhja publike e {actor} skadoi",
    "You shared {file} as public link" : "Ndatë {file} si një lidhje publike",
    "You removed public link for {file}" : "Hoqët lidhje publike për {file}",
    "Public link expired for {file}" : "Lidhja publike skadoi për {file}",
    "{actor} shared {file} as public link" : "{actor} u nda {file} si një lidhje publike",
    "{actor} removed public link for {file}" : "{actor} hoqi lidhje publike për {file}",
    "Public link of {actor} for {file} expired" : "Lidhja publike e {actor} për {file} ka skaduar",
    "{user} accepted the remote share" : "{user} pranoi ndarjen e largët",
    "{user} declined the remote share" : "{user} hodhi tej ndarjen e largët",
    "You received a new remote share {file} from {user}" : "Morët një ndarje të largët {file} nga {user}",
    "{user} accepted the remote share of {file}" : "{user} pranoi ndarjen e largët të {file}",
    "{user} declined the remote share of {file}" : "{user} hodhi tej ndarjen e largët të {file}",
    "{user} unshared {file} from you" : "{user} nuk ndau {file} nga ju",
    "Shared with {user}" : "Ndarë me {user}",
    "Removed share for {user}" : "Hoqi ndarjen për {user}",
    "{actor} shared with {user}" : "{aktori} ndau me {përdoruesin}",
    "{actor} removed share for {user}" : "{actor} hoqi ndarjen për {user}",
    "Shared by {actor}" : "U nda nga {actor}",
    "{actor} removed share" : "{actor} hoqi ndarjen",
    "You shared {file} with {user}" : "Ndatë {file} me {user}",
    "You removed {user} from {file}" : "Hoqët {user} nga {file}",
    "{actor} shared {file} with {user}" : "{aktori} ndau {skedarë} me {përdoruesin}",
    "{actor} removed {user} from {file}" : "{actor} hoqi {user} nga {file}",
    "{actor} shared {file} with you" : "{actor} ndau {skedarë} me ju",
    "A file or folder shared by mail or by public link was <strong>downloaded</strong>" : "Një skedar ose dosje e ndarë nga posta ose lidhja publike ishte <strong> shkarkuar</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "Një kartelë ose dosje u nda prej një <strong>shërbyesi tjetër</strong>",
    "A file or folder has been <strong>shared</strong>" : "U <strong>nda me të tjerë</strong> një kartelë ose dosje",
    "Wrong share ID, share doesn't exist" : "ID e gabuar ndarjeje, ndarja s’ekziston",
    "could not delete share" : "ndarja s’u fshi dot",
    "Could not delete share" : "Ndarja s’u fshi dot",
    "Please specify a file or folder path" : "Ju lutemi, tregoni një shteg kartele ose dosjeje",
    "Wrong path, file/folder doesn't exist" : "Shteg i gabuar, kratela/dosja s’ekziston",
    "Could not create share" : "Ndarja nuk u krijua dot",
    "invalid permissions" : "leje e pavlefshme",
    "Please specify a valid user" : "Ju lutemi, tregoni një përdorues të vlefshëm",
    "Group sharing is disabled by the administrator" : "Ndarja në grup është çaktivizuar nga përgjegjësi",
    "Please specify a valid group" : "Ju lutemi, tregoni një grup të vlefshëm",
    "Public link sharing is disabled by the administrator" : "Ndarja e lidhjeve publike është çaktivizuar nga përgjegjësi",
    "Public upload disabled by the administrator" : "Ngarkimi publik është çaktivizuar nga përgjegjësi",
    "Public upload is only possible for publicly shared folders" : "Ngarkimi publik është i mundshëm vetëm për dosje të ndara publikisht",
    "Invalid date, date format must be YYYY-MM-DD" : "Datë e pavlefshme, formati i datës duhet të jetë VVVV-MM-DD",
    "You cannot share to a Circle if the app is not enabled" : "Nuk mund të shpërndani në një rreth nëse aplikacioni nuk është i aktivizuar",
    "Please specify a valid circle" : "Ju lutem specifikoni një rreth i vlefshëm",
    "Unknown share type" : "Lloj i panjohur ndarjesh",
    "Not a directory" : "S’është drejtori",
    "Could not lock path" : "S’u kyç dot shtegu",
    "Wrong or no update parameter given" : "Ose u dha parametër i gabuar përditësimesh, pse s’u dha fare ",
    "Can't change permissions for public share links" : "S’mund të ndryshohen lejet për lidhje ndarjesh publike",
    "shared by %s" : "ndarë nga %s",
    "Direct link" : "Lidhje e drejtpërdrejtë",
    "Add to your Nextcloud" : "Shtojeni tek Nextcloud-i juaj",
    "Share API is disabled" : "API i ndarjeve është çaktivizuar",
    "Share" : "shpërndaj",
    "Sharing" : "Ndarje",
    "No entries found in this folder" : "S’u gjetën zëra në këtë dosje",
    "Name" : "Emër",
    "Share time" : "Kohë ndarjeje",
    "Expiration date" : "Datë skadimi",
    "Sorry, this link doesn’t seem to work anymore." : "Na ndjeni, kjo lidhje duket se nuk funksionon më.",
    "Reasons might be:" : "Arsyet mund të jenë:",
    "the item was removed" : "objekti është hequr",
    "the link expired" : "lidhja ka skaduar",
    "sharing is disabled" : "ndarjet janë çaktivizuar",
    "For more info, please ask the person who sent this link." : "Për më shumë të dhëna, ju lutemi, pyetni personin që ju dërgoi këtë lidhje.",
    "Download %s" : "Shkarko %s",
    "Upload files to %s" : "Ngrako skedarët tek %s",
    "Select or drop files" : "Përzgjidh ose hiq skedarët",
    "Uploading files…" : "Skedarët po ngarkohen...",
    "Uploaded files:" : "Skedarët e ngarkuar:",
    "Sharing %s failed because the back end does not allow shares from type %s" : "Ndarja e %s dështoi, ngaqë pjesa përgjegjëse e shërbyesit nuk lejon ndarje prej llojit %s"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-18.0.2.zip: nextcloud/apps/files_sharing/l10n/sq.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Shared with you" : "Të ndara me ju",
    "Nothing shared with you yet" : "Ende pa ndarë gjë me ju",
    "Files and folders others share with you will show up here" : "Këtu do të shfaqen kartelat dhe dosjet që të jerët ndajnë me ju",
    "Shared with others" : "Të ndara me të tjerët",
    "Nothing shared yet" : "Ende pa ndarë gjë",
    "Files and folders you share will show up here" : "Këtu do të shfaqen kartelat dhe dosjet që ndani me të tjerët",
    "Shared by link" : "Të ndara me lidhje",
    "No shared links" : "Pa lidhje ndarjesh",
    "Files and folders you share by link will show up here" : "Këtu do të shfaqen kartelat dhe dosjet që ndani përmes lidhjesh",
    "Deleted shares" : "Fshi shpërndarjet",
    "Shares" : "Shpërndarje",
    "Restore" : "Rikthe",
    "Download" : "Shkarko",
    "Delete" : "Delete",
    "You can upload into this folder" : "Mund të ngarkoni te kjo dosje",
    "Terms of service" : "Termat e shërbimit",
    "No compatible server found at {remote}" : "Asnjë server i pajtueshëm nuk është gjetur tek { }",
    "Invalid server URL" : "Server i pavlefshëm URL",
    "Failed to add the public link to your Nextcloud" : "Nuk arritët të shtoni ndërlidhjen publike tek Nextcloud juaj",
    "No expiration date set" : "Nuk është vendosur data e përfundimit",
    "Shared by" : "Ndarë nga",
    "File shares" : "Ndarja e skedarëve",
    "Downloaded via public link" : "Shkarkuar nga një link publik",
    "Downloaded by {email}" : "Shkarkuar nga {email}",
    "{file} downloaded via public link" : "{file} shkarkuar përmes një lidhjeje publike",
    "{email} downloaded {file}" : "{email} shkarkoi {file}",
    "Shared with group {group}" : "U nda me grupin {group}",
    "Removed share for group {group}" : "Hoqi ndarjen për grupin {group}",
    "{actor} shared with group {group}" : "{actor} u nda me grupin {group}",
    "{actor} removed share for group {group}" : "{actor} hoqi ndarjen për grupin {group}",
    "You shared {file} with group {group}" : "Ndatë {file} me grupin {group}",
    "You removed group {group} from {file}" : "Hoqët grupin {group} nga {file}",
    "{actor} shared {file} with group {group}" : "{actor} ndau {file} me grupin {group}",
    "{actor} removed group {group} from {file}" : "{actor} hoqi grupin {group} nga {file}",
    "Shared as public link" : "U nda si një lidhje publike",
    "Removed public link" : "Hoqi lidhje publike",
    "Public link expired" : "Lidhja publike skadoi",
    "{actor} shared as public link" : "{actor} u nda si një lidhje publike",
    "{actor} removed public link" : "{actor} hoqi lidhje publike",
    "Public link of {actor} expired" : "Lidhja publike e {actor} skadoi",
    "You shared {file} as public link" : "Ndatë {file} si një lidhje publike",
    "You removed public link for {file}" : "Hoqët lidhje publike për {file}",
    "Public link expired for {file}" : "Lidhja publike skadoi për {file}",
    "{actor} shared {file} as public link" : "{actor} u nda {file} si një lidhje publike",
    "{actor} removed public link for {file}" : "{actor} hoqi lidhje publike për {file}",
    "Public link of {actor} for {file} expired" : "Lidhja publike e {actor} për {file} ka skaduar",
    "{user} accepted the remote share" : "{user} pranoi ndarjen e largët",
    "{user} declined the remote share" : "{user} hodhi tej ndarjen e largët",
    "You received a new remote share {file} from {user}" : "Morët një ndarje të largët {file} nga {user}",
    "{user} accepted the remote share of {file}" : "{user} pranoi ndarjen e largët të {file}",
    "{user} declined the remote share of {file}" : "{user} hodhi tej ndarjen e largët të {file}",
    "{user} unshared {file} from you" : "{user} nuk ndau {file} nga ju",
    "Shared with {user}" : "Ndarë me {user}",
    "Removed share for {user}" : "Hoqi ndarjen për {user}",
    "{actor} shared with {user}" : "{aktori} ndau me {përdoruesin}",
    "{actor} removed share for {user}" : "{actor} hoqi ndarjen për {user}",
    "Shared by {actor}" : "U nda nga {actor}",
    "{actor} removed share" : "{actor} hoqi ndarjen",
    "You shared {file} with {user}" : "Ndatë {file} me {user}",
    "You removed {user} from {file}" : "Hoqët {user} nga {file}",
    "{actor} shared {file} with {user}" : "{aktori} ndau {skedarë} me {përdoruesin}",
    "{actor} removed {user} from {file}" : "{actor} hoqi {user} nga {file}",
    "{actor} shared {file} with you" : "{actor} ndau {skedarë} me ju",
    "A file or folder shared by mail or by public link was <strong>downloaded</strong>" : "Një skedar ose dosje e ndarë nga posta ose lidhja publike ishte <strong> shkarkuar</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "Një kartelë ose dosje u nda prej një <strong>shërbyesi tjetër</strong>",
    "A file or folder has been <strong>shared</strong>" : "U <strong>nda me të tjerë</strong> një kartelë ose dosje",
    "Wrong share ID, share doesn't exist" : "ID e gabuar ndarjeje, ndarja s’ekziston",
    "Could not delete share" : "Ndarja s’u fshi dot",
    "Please specify a file or folder path" : "Ju lutemi, tregoni një shteg kartele ose dosjeje",
    "Wrong path, file/folder doesn't exist" : "Shteg i gabuar, kratela/dosja s’ekziston",
    "Could not create share" : "Ndarja nuk u krijua dot",
    "invalid permissions" : "leje e pavlefshme",
    "Please specify a valid user" : "Ju lutemi, tregoni një përdorues të vlefshëm",
    "Group sharing is disabled by the administrator" : "Ndarja në grup është çaktivizuar nga përgjegjësi",
    "Please specify a valid group" : "Ju lutemi, tregoni një grup të vlefshëm",
    "Public link sharing is disabled by the administrator" : "Ndarja e lidhjeve publike është çaktivizuar nga përgjegjësi",
    "Public upload disabled by the administrator" : "Ngarkimi publik është çaktivizuar nga përgjegjësi",
    "Public upload is only possible for publicly shared folders" : "Ngarkimi publik është i mundshëm vetëm për dosje të ndara publikisht",
    "Invalid date, date format must be YYYY-MM-DD" : "Datë e pavlefshme, formati i datës duhet të jetë VVVV-MM-DD",
    "You cannot share to a Circle if the app is not enabled" : "Nuk mund të shpërndani në një rreth nëse aplikacioni nuk është i aktivizuar",
    "Please specify a valid circle" : "Ju lutem specifikoni një rreth i vlefshëm",
    "Unknown share type" : "Lloj i panjohur ndarjesh",
    "Not a directory" : "S’është drejtori",
    "Could not lock path" : "S’u kyç dot shtegu",
    "Wrong or no update parameter given" : "Ose u dha parametër i gabuar përditësimesh, pse s’u dha fare ",
    "Can't change permissions for public share links" : "S’mund të ndryshohen lejet për lidhje ndarjesh publike",
    "shared by %s" : "ndarë nga %s",
    "Direct link" : "Lidhje e drejtpërdrejtë",
    "Add to your Nextcloud" : "Shtojeni tek Nextcloud-i juaj",
    "Share API is disabled" : "API i ndarjeve është çaktivizuar",
    "File sharing" : "Shpërndarja e skedarëve",
    "Accept" : "Prano",
    "Sharing" : "Ndarje",
    "Allow editing" : "Lejo redaktimin",
    "Allow resharing" : "Lejo rindarje",
    "Set expiration date" : "Caktoni datë skadimi",
    "Note to recipient" : "Shënim për marrësin",
    "Unshare" : "Hiqe ndarjen",
    "group" : "grup",
    "conversation" : "bisedë",
    "remote" : "i largët",
    "guest" : "vizitor",
    "Link copied" : "Linku u kopjua",
    "Copy to clipboard" : "Kopjo në dërrasë ",
    "Only works for users with access to this folder" : "Punon vetëm për përdoruesit që kanë qasje në këtë dosje",
    "Password protection" : "Password protection",
    "Enter a password" : "Fusni një fjalëkalim",
    "Cancel" : "Anullo",
    "Read only" : "Vetëm i lexueshëm",
    "Allow upload and editing" : "Lejo ngarkim dhe editim",
    "File drop (upload only)" : "Lësho skedar (vetëm ngarkim)",
    "Hide download" : "Fshih shkarkimin",
    "Password protect" : "Mbroje me fjalëkalim",
    "Share link" : "Share link",
    "Resharing is not allowed" : "Nuk lejohet rishperndarja",
    "Shared" : "Ndarë",
    "Share" : "shpërndaj",
    "Shared with" : "Ndarë me",
    "Shared with you and the group {group} by {owner}" : "Ndarë me ju dhe me grupin {group} nga {owner}",
    "Shared with you by {owner}" : "Ndarë me ju nga {owner}",
    "No entries found in this folder" : "S’u gjetën zëra në këtë dosje",
    "Name" : "Emër",
    "Share time" : "Kohë ndarjeje",
    "Expiration date" : "Datë skadimi",
    "Sorry, this link doesn’t seem to work anymore." : "Na ndjeni, kjo lidhje duket se nuk funksionon më.",
    "Reasons might be:" : "Arsyet mund të jenë:",
    "the item was removed" : "objekti është hequr",
    "the link expired" : "lidhja ka skaduar",
    "sharing is disabled" : "ndarjet janë çaktivizuar",
    "For more info, please ask the person who sent this link." : "Për më shumë të dhëna, ju lutemi, pyetni personin që ju dërgoi këtë lidhje.",
    "Download %s" : "Shkarko %s",
    "Upload files to %s" : "Ngrako skedarët tek %s",
    "Note" : "Shënim",
    "Select or drop files" : "Përzgjidh ose hiq skedarët",
    "Uploading files…" : "Skedarët po ngarkohen...",
    "Uploaded files:" : "Skedarët e ngarkuar:",
    "could not delete share" : "ndarja s’u fshi dot"
},
"nplurals=2; plural=(n != 1);");
